summaryrefslogtreecommitdiffstats
path: root/kabc/vcardparser/vcardparser.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kabc/vcardparser/vcardparser.cpp')
-rw-r--r--kabc/vcardparser/vcardparser.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/kabc/vcardparser/vcardparser.cpp b/kabc/vcardparser/vcardparser.cpp
index a0e2061a4..67b1bc306 100644
--- a/kabc/vcardparser/vcardparser.cpp
+++ b/kabc/vcardparser/vcardparser.cpp
@@ -36,18 +36,18 @@ static TQString cr( "\\r" );
static void addEscapes( TQString &str )
{
- str.tqreplace( '\\', backslash );
- str.tqreplace( ',', comma );
- str.tqreplace( '\r', cr );
- str.tqreplace( '\n', newline );
+ str.replace( '\\', backslash );
+ str.replace( ',', comma );
+ str.replace( '\r', cr );
+ str.replace( '\n', newline );
}
static void removeEscapes( TQString &str )
{
- str.tqreplace( cr, "\\r" );
- str.tqreplace( newline, "\n" );
- str.tqreplace( comma, "," );
- str.tqreplace( backslash, "\\" );
+ str.replace( cr, "\\r" );
+ str.replace( newline, "\n" );
+ str.replace( comma, "," );
+ str.replace( backslash, "\\" );
}
VCardParser::VCardParser()
@@ -81,7 +81,7 @@ VCard::List VCardParser::parseVCards( const TQString& text )
continue;
} else {
if ( inVCard && !currentLine.isEmpty() ) { // now parse the line
- int colon = currentLine.tqfind( ':' );
+ int colon = currentLine.find( ':' );
if ( colon == -1 ) { // invalid line
currentLine = (*it);
continue;
@@ -94,14 +94,14 @@ VCard::List VCardParser::parseVCards( const TQString& text )
TQStringList params = TQStringList::split( ';', key );
// check for group
- if ( params[0].tqfind( '.' ) != -1 ) {
+ if ( params[0].find( '.' ) != -1 ) {
const TQStringList groupList = TQStringList::split( '.', params[0] );
vCardLine.setGroup( groupList[0] );
vCardLine.setIdentifier( groupList[1] );
} else
vCardLine.setIdentifier( params[0] );
- if ( params.count() > 1 ) { // tqfind all parameters
+ if ( params.count() > 1 ) { // find all parameters
TQStringList::ConstIterator paramIt = params.begin();
for ( ++paramIt; paramIt != params.end(); ++paramIt ) {
TQStringList pair = TQStringList::split( '=', *paramIt );
@@ -117,8 +117,8 @@ VCard::List VCardParser::parseVCards( const TQString& text )
pair.prepend( "type" );
}
}
- // This is pretty much a faster pair[1].tqcontains( ',' )...
- if ( pair[1].tqfind( ',' ) != -1 ) { // parameter in type=x,y,z format
+ // This is pretty much a faster pair[1].contains( ',' )...
+ if ( pair[1].find( ',' ) != -1 ) { // parameter in type=x,y,z format
const TQStringList args = TQStringList::split( ',', pair[ 1 ] );
TQStringList::ConstIterator argIt;
for ( argIt = args.begin(); argIt != args.end(); ++argIt )
@@ -134,7 +134,7 @@ VCard::List VCardParser::parseVCards( const TQString& text )
bool wasBase64Encoded = false;
params = vCardLine.parameterList();
- if ( params.tqfindIndex( "encoding" ) != -1 ) { // have to decode the data
+ if ( params.findIndex( "encoding" ) != -1 ) { // have to decode the data
TQByteArray input;
input = TQCString(value.latin1());
if ( vCardLine.parameter( "encoding" ).lower() == "b" ||
@@ -155,7 +155,7 @@ VCard::List VCardParser::parseVCards( const TQString& text )
output = TQCString(value.latin1());
}
- if ( params.tqfindIndex( "charset" ) != -1 ) { // have to convert the data
+ if ( params.findIndex( "charset" ) != -1 ) { // have to convert the data
TQTextCodec *codec =
TQTextCodec::codecForName( vCardLine.parameter( "charset" ).latin1() );
if ( codec ) {